@@ -1,18 +1,16 @@
 package Mail::DMARC::Report::AFRF;
 {
-  $Mail::DMARC::Report::AFRF::VERSION = '0.131260';
+  $Mail::DMARC::Report::AFRF::VERSION = '0.20130506';
 }
-# ABSTRACT: an AFRF report
 use strict;
 use warnings;
 
 use parent 'Mail::DMARC::Report';
 
-
-
 1;
+# ABSTRACT: an AFRF report
+
 
-__END__
 =pod
 
 =head1 NAME
@@ -21,9 +19,9 @@ Mail::DMARC::Report::AFRF - an AFRF report
 
 =head1 VERSION
 
-version 0.131260
+version 0.20130506
 
-=head1
+=head1 DESCRIPTION
 
 =head1 AUTHORS
 
@@ -35,7 +33,7 @@ Matt Simerson <msimerson@cpan.org>
 
 =item *
 
-Davide Migliavacca <davide.migliavacca@contactlab.com>
+Davide Migliavacca <shari@cpan.org>
 
 =back
 
@@ -48,3 +46,6 @@ the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
+__END__
+
