@@ -1,17 +1,16 @@
 package Mail::DMARC::Report::IODEF;
 {
-  $Mail::DMARC::Report::IODEF::VERSION = '0.131260';
+  $Mail::DMARC::Report::IODEF::VERSION = '0.20130506';
 }
-# ABSTRACT: an IODEF report
 use strict;
 use warnings;
 
 use parent 'Mail::DMARC::Report';
 
-
 1;
+# ABSTRACT: an IODEF report
+
 
-__END__
 =pod
 
 =head1 NAME
@@ -20,7 +19,7 @@ Mail::DMARC::Report::IODEF - an IODEF report
 
 =head1 VERSION
 
-version 0.131260
+version 0.20130506
 
 =head1 WHY IS THIS EMPTY?
 
@@ -28,8 +27,7 @@ https://datatracker.ietf.org/doc/draft-kucherawy-dmarc-base/?include_text=1
 
 Section 3.5 Out of Scope:
 
-    This first version of DMARC supports only a single reporting
-    format.
+    This first version of DMARC supports only a single reporting format.
 
 =head1 AUTHORS
 
@@ -41,7 +39,7 @@ Matt Simerson <msimerson@cpan.org>
 
 =item *
 
-Davide Migliavacca <davide.migliavacca@contactlab.com>
+Davide Migliavacca <shari@cpan.org>
 
 =back
 
@@ -54,3 +52,6 @@ the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
+__END__
+
